@@ -729,6 +729,9 @@ void KGet::settingsChanged()
 
     m_jobManager->settingsChanged();
     m_scheduler->settingsChanged();
+    if (!m_store)
+        m_store = TransferHistoryStore::getStore();
+    m_store->settingsChanged();
 }
 
 QList<TransferGroupHandler *> KGet::groupsFromExceptions(const QUrl &filename)
@@ -1630,3 +1633,5 @@ void GenericObserver::slotAbortAfterFinishAction()
 
     m_finishAction->stop();
 }
+
+#include "moc_kget.cpp"
