@@ -33,6 +33,7 @@
 
 #include <KLocalizedString>
 #include <KMessageBox>
+#include <kio_version.h>
 
 // TODO for 4.4 look at the changes of the newest Draft --> what elements have to be added/removed
 
@@ -166,7 +167,14 @@ void MetalinkCreator::createIntroduction()
     auto *widget = new QWidget(this);
     uiIntroduction.setupUi(widget);
 
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 108, 0)
+    uiIntroduction.save->setNameFilters(
+        {i18n("Metalink Version 4.0 file") + QLatin1String(" (*.meta4)"), i18n("Metalink Version 3.0 file") + QLatin1String(" (*.metalink)")});
+    uiIntroduction.load->setNameFilter(i18n("Metalink file (*.metalink *.meta4)") + QLatin1String(" (*.metalink *.meta4)"));
+#else
     uiIntroduction.save->setFilter("*.meta4|" + i18n("Metalink Version 4.0 file (*.meta4)") + "\n*.metalink|" + i18n("Metalink Version 3.0 file (*.metalink)"));
+    uiIntroduction.load->setFilter("*.metalink *.meta4|" + i18n("Metalink file (*.metalink *.meta4)"));
+#endif
     uiIntroduction.save->setAcceptMode(QFileDialog::AcceptSave);
 
     connect(uiIntroduction.save, &KUrlRequester::textChanged, this, &MetalinkCreator::slotUpdateIntroductionNextButton);
@@ -375,3 +383,5 @@ void MetalinkCreator::slotThreadFinished()
     uiFiles.dragDrop->hide();
     slotUpdateAssistantButtons(nullptr, m_files);
 }
+
+#include "moc_metalinkcreator.cpp"
